#ifndef _AFF_H
#define _AFF_H

#ifdef USE_LIBAFF

#include <afflib.h>

extern TSK_IMG_INFO *aff_open(const char **, TSK_IMG_INFO *);

typedef struct IMG_AFF_INFO IMG_AFF_INFO;

struct IMG_AFF_INFO {
    TSK_IMG_INFO img_info;
    AFFILE *af_file;
    OFF_T seek_pos;
    uint16_t type;              /* TYPE - uses AF_IDENTIFY_x values */
};

#endif

#endif
